{% extends 'admin/master.html' %}
{% from "security/_macros.html" import render_field, render_button, raise_error %}
{% block body %}
{{ super() }}
<div class="row-fluid">
    <div class="col-sm-8 col-sm-offset-2">
        <h1>Login</h1>
        <br>
        <div class="box">
            <form action="{{ url_for_security('login') }}" method="POST" name="login_user_form">
                {{ login_user_form.hidden_tag() }}
                {{ render_field(login_user_form.email) }}
                {{ render_field(login_user_form.password) }}
                {{ raise_error(login_user_form.email, login_user_form.password) }}
                {{ render_field(login_user_form.remember) }}
                {{ render_button(login_user_form.submit, class="btn btn-primary btn-md") }}
            </form>
        </div>
    </div>
</div>
{% endblock %}